/*
	Description: ASP.net page to demostrate the usage of the Zillow Mortgage API

	Author:  Robbie Paplin (robbiep at caffeinatedsoftware dot com)
	
	Copyright: (c) 2009 Caffeinated Software

	Legal: This software is distrubuted under the MIT license
	
	Permission is hereby granted, free of charge, to any person obtaining a copy of this software
	and associated documentation files (the "Software"), to deal in the Software without restriction, 
	including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense,
	and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so,
	subject to the following conditions:
	
	The above copyright notice and this permission notice shall be included in all copies or substantial 
	portions of the Software.
	
	THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT 
	LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
	IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
	WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
	SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

*/ 

using System;
using System.Text;
using System.IO;
using System.Collections;
using System.Xml;
using System.Net;
using System.Web;
using System.Web.UI;

namespace Caffeinated.TestPages
{
	// Helper class to store the response
	public class ZillowRateSummary
	{
		public int Is30YearFixedDown
		{
			get { return Math.Sign(Today30YearFixed -LastWeek30YearFixed); }
		}
		public int Is15YearFixedDown
		{
			get { return Math.Sign(Today15YearFixed -LastWeek15YearFixed); }
		}
	
		public int Is51ARMDown 
		{
			get { return Math.Sign(Today51ARM -LastWeek51ARM); }
		}
	
		public decimal Today30YearFixed;
		public decimal Today15YearFixed;
		public decimal Today51ARM;
		public decimal LastWeek30YearFixed;
		public decimal LastWeek15YearFixed;
		public decimal LastWeek51ARM;
	}

    public partial class ZillowDemoPage : System.Web.UI.Page
	{
		// Get your Zillow Web Services ID (ZWSID) at http://www.zillow.com/webservice/Registration.htm
		const string zwsid = "Your Zillow Web Services ID Goes Here!!!";

		protected static string GetTrendClass(int Trend)
		{
			if (Trend > 0)
			{
				return "rising";	
			}
			else if (Trend == 0)
			{
				return "steady";	
			}
			else
			{
				return "falling";
			}
		}

		protected static string GetTrendIcon(int Trend)
		{
			if (Trend > 0)
			{	
				// Unicode character for up arrow
				return "&#x25b2;";	
			}
			else if (Trend == 0)
			{
				return "No Change";	
			}
			else
			{
				// Unicode character for down arrow
				return "&#x25bc;";
			}
		}

		// The technical details of the GetRateSummary API are at http://www.zillow.com/howto/api/GetRateSummary.htm
        protected static ZillowRateSummary GetRateSummary()
        {
			// Construct the url
			String url = String.Format("http://www.zillow.com/webservice/GetRateSummary.htm?zws-id={0}", zwsid);
			ZillowRateSummary zrs = new ZillowRateSummary();
			try
			{
				// Make the HTTP request / get the response
				HttpWebRequest Request = (System.Net.HttpWebRequest)HttpWebRequest.Create(url);
				HttpWebResponse Response = (HttpWebResponse)Request.GetResponse();

				// Parse the HTTP response into an XML document
				XmlDocument xml = new XmlDocument();
				xml.Load(Response.GetResponseStream());
				XmlElement root = xml.DocumentElement;

				// Get today's rates via XPath
				XmlNode xmlNode = root.SelectSingleNode("//response/today/rate[@loanType='thirtyYearFixed']");
				zrs.Today30YearFixed = decimal.Parse(xmlNode.InnerText);
				xmlNode = root.SelectSingleNode("//response/today/rate[@loanType='fifteenYearFixed']");
				zrs.Today15YearFixed = decimal.Parse(xmlNode.InnerText);
				xmlNode = root.SelectSingleNode("//response/today/rate[@loanType='fiveOneARM']");
				zrs.Today51ARM = decimal.Parse(xmlNode.InnerText);
				
				// Get last weeks's rates via XPath
				xmlNode = root.SelectSingleNode("//response/lastWeek/rate[@loanType='thirtyYearFixed']");
				zrs.LastWeek30YearFixed = decimal.Parse(xmlNode.InnerText);
				xmlNode = root.SelectSingleNode("//response/lastWeek/rate[@loanType='fifteenYearFixed']");
				zrs.LastWeek15YearFixed = decimal.Parse(xmlNode.InnerText);
				xmlNode = root.SelectSingleNode("//response/lastWeek/rate[@loanType='fiveOneARM']");
				zrs.LastWeek51ARM = decimal.Parse(xmlNode.InnerText);
				
				Response.Close();
			}
			catch (Exception ex)
			{
			}

            return zrs;
        }
    }
}
